#
# spec file for package python-jupyterlab-templates
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pyver 0.5.0
%define distver 0.5
Name:           python-jupyterlab-templates
Version:        %{pyver}
Release:        2.1
Summary:        Templates for notebooks in JupyterLab
License:        Apache-2.0
URL:            https://github.com/finos/jupyterlab_templates
Source:         https://files.pythonhosted.org/packages/py3/j/jupyterlab_templates/jupyterlab_templates-%{version}-py3-none-any.whl
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module jupyterlab >= 4.0.0}
BuildRequires:  %{python_module notebook}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  jupyter-jupyterlab-filesystem
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  python-rpm-macros
Requires:       jupyter-jupyterlab-templates = %{version}
Requires:       python-jupyterlab >= 4.0
Requires:       (python-notebook if python-jupyterlab >= 4)
Conflicts:      jupyter-jupyterlab_templates < %{version}
Provides:       python-jupyter_jupyterlab_templates = %{version}
Obsoletes:      python-jupyter_jupyterlab_templates < %{version}
BuildArch:      noarch
%python_subpackages

%description
Support for jupyter notebook templates in jupyterlab.

%package     -n jupyter-jupyterlab-templates
Summary:        Templates for notebooks in JupyterLab
Requires:       jupyter-jupyterlab >= 4.0.0
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(jupyterlab-templates) = %{distver}
Suggests:       python3-jupyterlab-templates
Provides:       jupyter-jupyterlab_templates = %{version}
Obsoletes:      jupyter-jupyterlab_templates < %{version}

%description -n jupyter-jupyterlab-templates
Support for jupyter notebook templates in jupyterlab.

%prep
%setup -q -c -T

%build
%{python_expand mkdir build/; cp -a %{SOURCE0} build/}

%install
%pyproject_install
%jupyter_move_config
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_jupyter_prefix}
find  %{buildroot} -path '*/jupyterlab_templates-%{version}.dist-info/licenses' -exec cp -r {} ./ ';' -quit

%check
%pytest --pyargs jupyterlab_templates

%files %{python_files}
%license licenses/*
%{python_sitelib}/jupyterlab_templates-%{version}.dist-info/
%{python_sitelib}/jupyterlab_templates/

%files -n jupyter-jupyterlab-templates
%license licenses/*
%{_jupyter_config} %{_jupyter_server_confdir}/jupyterlab_templates.json
%{_jupyter_prefix}/labextensions/jupyterlab_templates
%dir %{_jupyter_prefix}/notebook
%{_jupyter_prefix}/notebook/jupyterlab_templates

%changelog
* Thu Aug 17 2023 Ben Greiner <code@bnavigator.de>
- Suggest primary python package -- boo#1214354
* Sat Aug  5 2023 Arun Persaud <arun@gmx.de>
- specfile:
  * require jupyterlab >=4 (according to metadata in wheel)
- update to version 0.5.0:
  * Support JupyterLab 4
  * Bump semver from 5.7.1 to 5.7.2 in /js
  * Bump tough-cookie from 4.1.2 to 4.1.3 in /js
- changes from version 0.4.1:
  * fix lint
  * add allowed_extensions setting
  * switch from notebook handler to jupyter server handler
  * Bump yaml from 2.2.1 to 2.2.2 in /js
  * publish junit test results for js and python
  * fix typo and capitalize repository links
* Tue Jun 13 2023 Ben Greiner <code@bnavigator.de>
- Jupyterlab 4 does not hard require notebook anymore:
  get it explicitly
* Sun Apr 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.4.0
  * fix manifest to exclude node_modules and built assets by
    @timkpaine in #177
  * Clean up references and add files for FINOS move by @timkpaine
    in #181
  * add security checks, add license checks, prune docs by
    @timkpaine in #180
  * fixes #167 for new jupyter-server by @timkpaine in #200
  * Use nb server logging instead of print by @toslunar in #202
* Tue Jan  3 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.3.2
  * Maintenance release without release notes
- Update macro usage
- Remove invalid PEP440 specifier in dev-extra which made
  pythondistdeps.py choke
* Sun Nov 14 2021 Ben Greiner <code@bnavigator.de>
- Allow to keep the config in %%_distconfdir
* Fri Nov 12 2021 Ben Greiner <code@bnavigator.de>
- Update o 0.3.1
  * Drop python 3.6
  * Add python 3.9
  * Fix bugs with JLab 3.0
  * Dist with prebuilt extension
* Thu Feb  4 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.3.0
  * No upstream changelog. Mostly internal changes.
- Fix wheel install location for pyproject_install
- Enable tests
* Sun May 24 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix download url
* Sat Apr 25 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.2.3:
  * set long description type
* Mon Dec 16 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Use pyproject_install macro (boo#1094323)
* Thu Dec 12 2019 Todd R <toddrme2178@gmail.com>
- Fix conflict with old version
* Mon Dec  9 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.2.2
  * Fix random typos
  * Refactor setup.py and add make fix
  * Allow for opting out of core paths
- Rename spec file to python-jupyterlab-templates to work better
  with OSC python tooling.
* Wed Nov 27 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.2.1
  * Reload templates on disk
* Sat Jul 27 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.2.0
  * JupyterLab 1.0.0 support
  * Will now scan standard locations for vendor notebooks
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Fix dependency name
* Mon Apr 29 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.0.8
  * Allow to delete default template #20
  * Docs update/formatting/bugfixes/better linting/move to pytest
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match jupyter package naming guidelines.
* Thu Sep 20 2018 Todd R <toddrme2178@gmail.com>
- Disable python2 build since jupyterlab no longer supports python2
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 0.0.7
  * fixing icon
  * remove ujson
  * badges
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 0.0.5
  * fixing #10 svg parsing error for icon
  * fixed missing template names in firefox
* Sun Jun 10 2018 jengelh@inai.de
- Avoid bashism in scriptlet.
* Tue May 29 2018 toddrme2178@gmail.com
- Use || true syntax instead of exit 0
* Thu May  3 2018 toddrme2178@gmail.com
- Use %%license tag
* Fri Apr 20 2018 toddrme2178@gmail.com
- Initial version
